@@ -7,10 +7,12 @@ import itertools
 from sklearn.neural_network import MLPClassifier
 from copy import deepcopy
 from .briefrecord import BriefRecFactory
+from .common import deprecated
 
 from typing import Callable, List, Tuple, Dict, Any, Optional
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 def convert_to_numeric(txt: str) -> str:
     """convert_to_numeric(str) -> str
     Convert a text number to a numeric string.
@@ -62,6 +64,7 @@ def handling_missing_values(fn: Callable) -> Callable:
     return wrapper
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 def get_ascii(txt: str) -> str:
     """get_ascii(txt: str) -> str
     Return the ascii version of a string.
@@ -73,6 +76,7 @@ def get_ascii(txt: str) -> str:
     return unicodedata.normalize('NFD', txt).encode('ascii', 'ignore').decode().upper()
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 @handling_missing_values
 def evaluate_year(year1: int, year2: int) -> float:
     """evaluate_year(year1: int, year2: int) -> float
@@ -86,9 +90,10 @@ def evaluate_year(year1: int, year2: int) -> float:
     return 1 / ((abs(year1 - year2) * .5) ** 2 + 1)
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 @handling_missing_values
-def evaluate_identifiers(ids1: str, ids2: str) -> float:
-    """evaluate_identifiers(ids1: str, ids2: str) -> float
+def evaluate_identifiers(ids1: List[str], ids2: List[str]) -> float:
+    """evaluate_identifiers(ids1: List[str], ids2: List[str]) -> float
     Return the result of the evaluation of similarity of two lists of identifiers.
 
     :param ids1: list of identifiers to compare
@@ -105,6 +110,48 @@ def evaluate_identifiers(ids1: str, ids2: str) -> float:
         return 0
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
+@handling_missing_values
+def evaluate_isbns(ids1: List[str], ids2: List[str]) -> float:
+    """evaluate_isbns(ids1: List[str], ids2: List[str]) -> float
+    Return the result of the evaluation of similarity of two lists of identifiers.
+
+    :param ids1: list of isbns to compare
+    :param ids2: list of isbns to compare
+
+    :return: similarity score between two lists of identifiers as float
+    """
+    def normalize_isbns(isbns: list[str]) -> List[str]:
+        """Return a normalized list of ISBNs
+
+        Idea is to transform all ISBNs in a 13 digit verstion. To avoid caluculating
+        the last control, it is removed. All ISBN have 12 digits. Incorrect isbns with
+        other lengths are kept as they are.
+
+        :param isbns: list of ISBN to complete with variants
+
+        :return: normalized version of the ISBN
+        """
+        new_isbns = []
+        for isbn in isbns:
+            if len(isbn) == 13:
+                new_isbns.append(isbn[:12])
+            if len(isbn) == 10:
+                new_isbns.append('978' + isbn[:9])
+            else:
+                new_isbns.append(isbn)
+        return new_isbns
+
+    ids1 = set(normalize_isbns(ids1))
+    ids2 = set(normalize_isbns(ids2))
+    if len(set.union(ids1, ids2)) > 0:
+        score = len(set.intersection(ids1, ids2)) / len(set.union(ids1, ids2))
+        return score ** .05 if score > 0 else 0
+    else:
+        return 0
+
+
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 @handling_missing_values
 def evaluate_sysnums(ids1: str, ids2: str) -> float:
     """evaluate_identifiers(ids1: str, ids2: str) -> float
@@ -144,6 +191,7 @@ def evaluate_sysnums(ids1: str, ids2: str) -> float:
         return 0
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 @handling_missing_values
 def evaluate_language(lang1: str, lang2: str) -> float:
     """evaluate_language(lang1: str, lang2: str) -> float
@@ -160,6 +208,7 @@ def evaluate_language(lang1: str, lang2: str) -> float:
         return 0
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 def evaluate_is_analytical(format1: str, format2: str) -> float:
     """evaluate_is_analytical(format1: str, format2: str) -> float
     Check if records are analytical records
@@ -177,6 +226,7 @@ def evaluate_is_analytical(format1: str, format2: str) -> float:
         return 0
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 def evaluate_is_series(format1: str, format2: str) -> Optional[float]:
     """evaluate_is_series(format1: str, format2: str) -> Optional[float]
     Check if records are series
@@ -195,6 +245,7 @@ def evaluate_is_series(format1: str, format2: str) -> Optional[float]:
         return 0
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 @handling_missing_values
 def evaluate_extent(extent1: List[int], extent2: List[int]) -> float:
     """evaluate_extent(extent1: List[int], extent2: List[int]) -> float
@@ -230,6 +281,7 @@ def evaluate_extent(extent1: List[int], extent2: List[int]) -> float:
     return (score1 + score2 + score3) / 3
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 def get_unique_combinations(l1: List[str], l2: List[str]) -> List[List[Tuple]]:
     """get_unique_combinations(l1: List[str], l2: List[str]) -> List[List[Tuple]]
     Used to search the best match with names like authors or publishers.
@@ -253,6 +305,7 @@ def get_unique_combinations(l1: List[str], l2: List[str]) -> List[List[Tuple]]:
     return unique_combinations
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 @handling_missing_values
 def evaluate_lists_texts(texts1: List[str], texts2: List[str]) -> float:
     """evaluate_lists_texts(texts1: List[str], texts2: List[str]) -> float
@@ -271,6 +324,7 @@ def evaluate_lists_texts(texts1: List[str], texts2: List[str]) -> float:
     return max([np.mean([evaluate_texts(*p) for p in comb]) for comb in unique_combinations])
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 @handling_missing_values
 def evaluate_lists_names(names1: List[str], names2: List[str]) -> float:
     """evaluate_lists_names(names1: List[str], names2: List[str]) -> float
@@ -312,6 +366,7 @@ def evaluate_lists_names(names1: List[str], names2: List[str]) -> float:
         return np.mean(sorted(scores, reverse=True)[:4])
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 @handling_missing_values
 def evaluate_names(name1: str, name2: str) -> float:
     """evaluate_names(name1: str, name2: str) -> float
@@ -365,6 +420,7 @@ def evaluate_names(name1: str, name2: str) -> float:
     return 1 / (sum([s[2] for s in scores]) + 1)
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 @handling_missing_values
 def evaluate_texts(text1: str, text2: str) -> float:
     """evaluate_texts(text1: str, text2: str) -> float
@@ -405,6 +461,7 @@ def evaluate_texts(text1: str, text2: str) -> float:
     return (score_raw + score_ascii * 4) / 5 * coef
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 @handling_missing_values
 def evaluate_format(format1: str, format2: str) -> float:
     """evaluate_format(format1: str, format2: str) -> float
@@ -437,6 +494,7 @@ def evaluate_format(format1: str, format2: str) -> float:
     return score
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 @handling_missing_values
 def evaluate_parents(parent1: Dict, parent2: Dict) -> float:
     """evaluate_parents(parent1: Dict, parent2: Dict) -> float
@@ -520,6 +578,7 @@ def evaluate_parents(parent1: Dict, parent2: Dict) -> float:
                                   if s is not None])
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 @handling_missing_values
 def evaluate_editions(texts1: List[str], texts2: List[str]) -> float:
     """evaluate_editions(texts1: List[str], texts2: List[str]) -> float
@@ -549,6 +608,7 @@ def evaluate_editions(texts1: List[str], texts2: List[str]) -> float:
         return score_txt
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 @handling_missing_values
 def evaluate_completeness(bib1: Dict[str, Any], bib2: Dict[str, Any]) -> float:
     """evaluate_completeness(bib1: Dict[str, Any], bib2: Dict[str, Any]) -> float
@@ -570,6 +630,7 @@ def evaluate_completeness(bib1: Dict[str, Any], bib2: Dict[str, Any]) -> float:
     return 1 / (1 + (len(bib1) - nb_common_existing_fields))
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 def evaluate_similarity(bib1: Dict[str, Any], bib2: Dict[str, Any]) -> Dict[str, float]:
     """evaluate_similarity(bib1: Dict[str, Any], bib2: Dict[str, Any]) -> Dict[str, float]
     The function returns a dictionary with keys corresponding to the fields of the bib
@@ -592,7 +653,7 @@ def evaluate_similarity(bib1: Dict[str, Any], bib2: Dict[str, Any]) -> Dict[str,
         'publishers': evaluate_lists_texts(bib1['publishers'], bib2['publishers']),
         'series': evaluate_lists_texts(bib1['series'], bib2['series']),
         'extent': evaluate_extent(bib1['extent'], bib2['extent']),
-        'isbns': evaluate_identifiers(bib1['isbns'], bib2['isbns']),
+        'isbns': evaluate_isbns(bib1['isbns'], bib2['isbns']),
         'issns': evaluate_identifiers(bib1['issns'], bib2['issns']),
         'other_std_num': evaluate_identifiers(bib1['other_std_num'], bib2['other_std_num']),
         'parent': evaluate_parents(bib1['parent'], bib2['parent']),
@@ -604,6 +665,7 @@ def evaluate_similarity(bib1: Dict[str, Any], bib2: Dict[str, Any]) -> Dict[str,
     return results
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 def get_similarity_score(bib1: Dict[str, Any],
                          bib2: Dict[str, Any],
                          clf: Optional[MLPClassifier] = None,
