@@ -4,7 +4,7 @@ import unittest
 import shutil
 
 config_log()
-SruClient.set_base_url('https://swisscovery.slsp.ch/view/sru/41SLSP_NETWORK')
+SruClient.set_base_url('https://swisscovery.ch/view/sru/41SLSP_NETWORK')
 
 
 class TestSruClient(unittest.TestCase):
@@ -74,7 +74,7 @@ class TestSruClient(unittest.TestCase):
         analysis = rec.get_child_rec()
         self.assertEqual(analysis['related_records_found'], True, 'Related records for "991159842549705501"'
                                                                   ' should have been found')
-        self.assertEqual(analysis['number_of_rel_recs'], 8, 'It should be 8 related records for "991159842549705501"')
+        self.assertGreater(analysis['number_of_rel_recs'], 10, 'It should be 8 related records for "991159842549705501"')
         self.assertTrue(SruRecord('991171058106405501') in analysis['related_records'],
                         'Record "991171058106405501" should be in related records set')
         self.assertTrue({'child_MMS_ID': '991171058106405501',
